@@ -1,31 +1,32 @@
 package File::Find::Rule::DirectoryEmpty;
 use strict;
 use base 'File::Find::Rule';
-use vars qw($VERSION);
-$VERSION = sprintf "%d.%02d", q$Revision: 1.6 $ =~ /(\d+)/g;
+
+our $VERSION = sprintf "%d.%02d", q$Revision: 1.9 $ =~ /(\d+)/g;
 
 
 sub File::Find::Rule::directoryempty {
 	my $self = shift->_force_object;
 
-
+#	$self->directory;
+	
 	$self->exec( 
 		sub {
 			opendir(DIR,+shift) or return;	
-
-         for( readdir DIR ){
-            if( !/^\.\.?$/ ){
-               closedir DIR;
-               return 0;
-            }
-         }
-         closedir DIR;
-         return 1;            
+			my $count = scalar(grep{!/^\.\.?$/} readdir DIR);
+			closedir DIR;
+			return ($count==0);	
 		}
-	);		
+	);	
+	
 }
 
 	
+#    my $dh = IO::Dir->new($fullname) or return;
+#    my $count = scalar(grep{!/^\.\.?$/} $dh->read());
+#    $dh->close();
+#    return($count==0);
+#}
 
 
 1;
@@ -36,7 +37,7 @@ __END__
 
 =head1 NAME
 
-File::Find::Rule::DirectoryEmpty - find empty directories recursively
+File::Find::Rule::DirectoryEmpty - test a directory for being empty
 
 =head1 SYNOPSIS
 
@@ -48,12 +49,6 @@ File::Find::Rule::DirectoryEmpty - find empty directories recursively
 
 returns boolean
 
-=head1 DESCRIPTION
-
-Instead of reading full count of directory contents, we return false as soon as we match
-something other then . or ..
-This may not work on windoze.
-
 =head1 AUTHOR
 
 Leo Charre leocharre at cpan dot org
